@@ -1,5 +1,5 @@
-mod alignment;
 mod alignment_ext;
+mod alignment_impl;
 mod bamfile;
 mod cigar_ext;
 pub mod error;
@@ -8,6 +8,6 @@ mod map_ext;
 mod nucleotide;
 mod seq_ext;
 
-pub use alignment::{Alignment, AlignmentIter, AlignmentReader};
+pub use alignment_impl::{Alignment, AlignmentIter, AlignmentReader};
 pub use bamfile::BamFile;
 pub use nucleotide::Nucleotide;
